//Jeremy Blum's Arduino Tutorial Series - Episode 13 - LCDs
//Sample Code - LCD Progress Bar
//http://www.jeremyblum.com
//LiquidCrystal library by David A. Mellis, Limor Fried (http://www.ladyada.net), and Tom Igoe
//http://www.arduino.cc/en/Tutorial/LiquidCrystal
//More information on the sensor is available in the datasheet:
// http://dlnmh9ip6v2uc.cloudfront.net/datasheets/Sensors/Temp/TMP35_36_37.pdf
//Additional code integration from SparkFun Inventor's Kit 
//Example sketch 07
//Visit http://learn.sparkfun.com/products/2 for SIK information.
// Modified by David Morgan (davemorganster@gmail.com)

/* 
  The circuit:
 * LCD RS pin to digital pin 2
 * LCD Enable pin to digital pin 3
 * LCD D4 pin to digital pin 4
 * LCD D5 pin to digital pin 5
 * LCD D6 pin to digital pin 6
 * LCD D7 pin to digital pin 7
 * LCD R/W pin to ground
 * 10K resistor #1:
 * ends to +5V and ground
 * wiper to LCD VO pin (pin 3)
 * 10K resistor #2:
 * ends to +5V and ground
 * wiper to LCD LED+ pin (pin 15)
 */

// include the library code:
#include <LiquidCrystal.h>

// initialize the library with the numbers of the interface pins
LiquidCrystal lcd(2, 3, 4, 5, 6, 7);


byte hrt1[8] = {
  B01010,
  B10101,
  B01010,
  B00100,
  B00000,
  B00000,
  B00000,
};

byte hrt2[8] = {
  B00000,
  B01010,
  B10101,
  B01010,
  B00100,
  B00000,
  B00000,
};

byte hrt3[8] = {
  B00000,
  B00000,
  B01010,
  B10101,
  B01010,
  B00100,
  B00000,
};

byte hrt4[8] = {
  B00000,
  B00000,
  B00000,
  B01010,
  B10101,
  B01010,
  B00100,
};

byte degree[8] = {
  B00110,
  B01001,
  B01001,
  B00110,
  B00000,
  B00000,
  B00000,
};

void setup() {
  
  //Make heartbeat characters
  lcd.createChar(0, hrt1);
  lcd.createChar(1, hrt2);
  lcd.createChar(2, hrt3);
  lcd.createChar(3, hrt4);
 
 //Make degree character
 
  lcd.createChar(4, degree);
}

void loop() {
  
  //Print text for row 1
  
  lcd.print("Room Temp.      ");
  
  //Set up nested loops for hearbeat at end of row
  for (int i = 12; i < 16; i++)
  {
    for (int j = 0; j < 4; j++)
    {
      lcd.setCursor(i, 0);
      lcd.write(j);
      delay(100);
    }
  }
  //Get data from TMP36 temp sensor on pin A0
  const int temperaturePin = 0;
  lcd.setCursor(0,1);
  float voltage, degreesC, degreesF;
  
  // First we'll measure the voltage at the analog pin. Normally
  // we'd use analogRead(), which returns a number from 0 to 1023.
  // Here we've written a function (further down) called
  // getVoltage() that returns the true voltage (0 to 5 Volts)
  // present on an analog input pin.
  
  voltage = getVoltage(temperaturePin);
  
  // Now we'll convert the voltage to degrees Celsius.
  // This formula comes from the temperature sensor datasheet:
  
  degreesC = (voltage - 0.5) * 100;
  
  // While we're at it, let's convert degrees Celsius to Fahrenheit.
  // This is the classic C to F conversion formula:
  
  degreesF = (degreesC/5) * 9 + 32;
  
  //Now we're going to print it to the LCD display

  // set up the LCD's number of columns and rows: 
  lcd.begin(16,2);
  
  //Set cursor position to column 1 row 1
  
  lcd.setCursor(0, 0);
  
    //Print text for row 1
  
  lcd.print("Room Temp.      ");
  
  //Set up nested loops for hearbeat at end of row
  for (int i = 12; i < 16; i++)
  {
    
    for (int j = 0; j < 4; j++)
    {
      lcd.setCursor(i, 0);
      lcd.write(j);
      }
  }
  //Printing temps on second row of LCD
  
  lcd.setCursor(0,1);
  lcd.print(degreesC);
  lcd.write(4);
  lcd.print("C, ");
  lcd.print(degreesF);
  lcd.write(4);
  lcd.print("F");
   
  delay(1000); // repeat once per second (change as you wish!)
}
float getVoltage(int pin)
// This function has one input parameter, the analog pin number
// to read. You might notice that this function does not have
// "void" in front of it; this is because it returns a floating-
// point value, which is the true voltage on that pin (0 to 5V).

{
// Here's the return statement for this function. We're doing
// all the math we need to do within this statement:

return (analogRead(pin) * 0.004882814);
}
